==> haskell-postgresql-simple-0.6.5-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-simple
version:              0.6.5
visibility:           public
id:                   postgresql-simple-0.6.5-Eri4CbLEV5y1betDtBlBMo
key:                  postgresql-simple-0.6.5-Eri4CbLEV5y1betDtBlBMo
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  0596bd2d234439ef294f7577fc468aa4
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/postgresql-simple-0.6.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/postgresql-simple-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5-Eri4CbLEV5y1betDtBlBMo
depends:
    Only-0.1-L8QgoWg4Wjg75H1UNFo3nI
    aeson-2.1.2.1-AoiZ9fpfbxJ47564nNIIBq
    attoparsec-0.14.4-9KhLweOrk4jAI2XTloxgeh base-4.15.1.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-22stPLnoxWFCGU5IfVuolg containers-0.6.4.1
    hashable-1.4.2.0-ACOKJtOF9viKWyhESTEaY8
    postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy
    scientific-0.3.7.0-K0ypbSyuCqS5Fd30xEyG2S template-haskell-2.17.0.0
    text-1.2.5.0 time-compat-1.9.6.1-Ap94Is67s7s4YONZEI5xBt
    transformers-0.5.6.2 uuid-types-1.0.5-LWAtvAxEBmL9aa5ZYLC5yU
    vector-0.13.0.0-AvCgqYhQ3vmCYiPnKivqd

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-simple-0.6.5-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-simple
version:              0.6.5
visibility:           public
id:                   postgresql-simple-0.6.5-F6KLRrx3uL2BvSUrW9Gjjv
key:                  postgresql-simple-0.6.5-F6KLRrx3uL2BvSUrW9Gjjv
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  a779814df95b2d04844f58fa881c4939
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/postgresql-simple-0.6.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/postgresql-simple-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5-F6KLRrx3uL2BvSUrW9Gjjv
depends:
    Only-0.1-L8QgoWg4Wjg75H1UNFo3nI
    aeson-2.1.2.1-GnWfeeQpoVOBig4HoIDDG9
    attoparsec-0.14.4-10U3JVdOf0KJjxjEqAIrEh base-4.15.1.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-6HwZPMiOaK97nwlWoHY1Gb containers-0.6.4.1
    hashable-1.4.2.0-8EyZ5q0qf6V2oPuIX4Sz4t
    postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy
    scientific-0.3.7.0-AejKlNxs4tarEm4tm38IP template-haskell-2.17.0.0
    text-1.2.5.0 time-compat-1.9.6.1-4h5NKkODTuiGLtKDFX6lVD
    transformers-0.5.6.2 uuid-types-1.0.5-5ES172aQypTCiUGXUIWnmx
    vector-0.13.0.0-DcAY6cFNWmp2QJjfa2GrVo

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
